@@ -92,7 +92,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::customer::Address;
             use checkout_core::shipping::FulfillmentTypeSelection;
             use checkout_core::server::IdParam;
-            use checkout_core::server::CreateBodyParams;
+            use checkout_core::server::CreateParams;
             use checkout_core::server::AddOrRemoveItemBodyParams;
             use checkout_core::transaction::TransactionController;
             use checkout_core::context::Context;
@@ -100,11 +100,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler};
 
             pub struct Config {
-                google_application_credentials: String
+                pub google_application_credentials: String
             }
 
             pub fn get_config() -> Config {
-                ServerConfig {
+                Config {
                     google_application_credentials: env::var("GOOGLE_APPLICATION_CREDENTIALS").unwrap(),
                 }
             }
@@ -120,7 +120,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             }]
             pub async fn create_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
-                body: TypedBody<CreateBodyParams>,
+                body: TypedBody<CreateParams>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let params = body.into_inner();
                 let mut ctx = req_ctx
@@ -370,7 +370,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<<super::context_type_name as PaymentProcessor>::InitiateArgs>,
+                body: TypedBody<<super::#context_type_name as PaymentProcessor>::InitiateArgs>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -435,7 +435,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let config = checkout_server::get_config();
 
-                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone()).map_err(|_| checkout_server::Error {
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone()).await.map_err(|_| checkout_server::Error {
                     code: "500".to_string(),
                     message: "failed to create internal context".to_string(),
                 })?;
